I would like to create a new way to work with project value delivery from ideation to requirement to implmentation ... to feedback and replanning.
it's called Engineering-Workflow.

the engineering workflow entry should be on x-ipe top menu on the left side of knowledge menu.

when I click on enginerring workflow, it should switch the middle content(the sidebar menu and the content view) to workflow mode and show workflow view.

here let's reference the design "engineering-workflow-reference.png"


for the workflow view. it should be group by each engeering-workflow, and workflow can be created by click the top right button "+ Create Workflow".

## + Create Workflow:
- it should bring a modal window. in the model window, there is a text box for typing workflow name.
- and there is a button to confirm the creation.

after creating the workflow. it should just like the referenced mockup, that there should be a panel created for the workflow.

## panel created for the workflow
- in the panel of the workflow, the top part are the actions we can take for each stage in the project value delivery, such as Compose/Upload Idea, Reference UIUX, Requirement Gathering, etc.
- the bottom part are the deliverables generated by taking the actions above.

## the logic behind taking the actions in the workflow
- the action button having 3 style, one is done action(the button should be in green background), which indicates the action has been executed, and generated deliverables. the second is suggest to do next(the button border should be in dash yellow), the 3rd is normal, you can work on it but not suggested. 
- and these color and status should be changed dynamically during the progress of the execution in the workflow.
- at beiggining, the ideation action should in dash yellow.

## the interaction with the action button in the workflow
- when click on an action button, base on different action it may have different ux. it can simply split into two.
  > open modal window, for example compose/upload idea. opens a modal window to compose idea in md format or upload from local device. (the function can reuse existing idea composing/uploading function but in a modal instead of on a page). after generating the idea file, it should apear in the bottom part of the workflow panel
  > agent cli interaction. for example refine the idea. it should expend the console window, and create a new session in the console window and type the related prompt to turn on cli with instructions. for example for idea refinement. bring the console window, create a new session, then typing copilot "refine xxxxxidea.md"
- different action may have different options, but the idea is to reuse existing flow with a centralized and workflow based mode.

## agent cli interaction
- after bring up cli and exeucting the instruction, in order for application and agent more accurate interaction. in stead of existing output standard defined in Agent Skills, we will also extend existing app-agent-interaction mcp. for each action which using skills, after these skills finish it's work and generate result, these skills should call app-agent-interaction mcp to pass the result to the mcp then generate the notification and show the result in x-ipe-workflow view(mcp output maybe more stable then agent, and better error handling.)

let's me just give these requirements first, let's refine the idea together.